function [vertices,normals,colors,faces,saliency,saliencymark] = GetSalientVertices(dir,filename,varargin)
%This function extracts saliency vertices of a .ply mesh.
%INPUT: directory of the .ply file, filename.ply, parameters,visualoutput
%Parameters:a vector of 1,4 or 7 elements
%7 parameters: 
%Set_BB_epsilon_percentage(i.e 0.003) :percentage of the bounding box main diagonal used to set the epsilon value 
%Set_T_Inibition(i.e 0.75)            : inibition Threshold is used for each map: a map is set to zero if the number of map value of neighbours at dist Inibition_distance_BB_percentage is minor of the percentage
%Set_Inibition_distance_BB_percentage(i.e. 0.05): distance used to evaluate neighbours in the inibition phase, 
%Set_NonMax_suppression_num_of_salient_vertices(i.e 100)    : number of salient vertices to set on the model.Vertices are set by sorting the sum of map values
%Set_NonMax_Suppression_percentage(i.e. 0.2)                : the neighbours of a vertex are set to zero if their saliency value is higher than this threshold percentage
%Set_NonMax_Suppression_distance_BB_percentage(i.e. 0.07)   : distance used for the non maximum suppression phase, a percentage of the mesh main diagonal      
%Set_Resolution_mult_factor_for_tagboundary(i.e. 2)         :in case of not closed meshes, set this value to inibit the possibility of salient vertices closed to the boundaries                  
%
%param = [0.003,0.75,0.05,100,0.2,0.07,2];
%
%4 parameters: set values for 
%   BB_epsilon_percentage();
%   T_Inibition();
%   Inibition_distance_BB_percentage();
%   Gparam.Set_NonMax_suppression_num_of_salient_vertices();
%
%   param = [0.003,0.75,0.05,100];
%
%1 parameter: set the number of salient vertices required,all the other parameters have standard settings
%   param = [100];
%visualouput: true or flase(bool value);
%OUTPUT:vertices,normals,faces,saliency (saliency value),saliency mark(1 if salient, 0 if not)
%param = [100];
% es: [vertices,normals,colors,faces,saliency,saliencymark] = GetSalientVertices(dir,filename,param,'true');
%
%
% by Umberto Castellani, Maurizio Galassi, and Simone Fantoni
%
% U. Castellani, M. Cristani, S. Fantoni, V. Murino. Sparse points matching
% by combining 3D mesh saliency with statistical descriptors. Computer Graphics Forum. Vol. 27, No. 2, 2008, pp. 643-652
%
%
    optargin = size(varargin,2);
    stdargin = nargin - optargin;
    fprintf('Number of inputs = %d\n', nargin)

    if(nargout<6)
         error('6 output required:i.e. [vertices,normals,colors,faces,saliency,saliencymark] ');    
    end
    if(nargin<2)
        error('At least 2 inputs are required:filedirectory and filename for.ply mesh');
    end
    if(nargin==2 )    
        param = 100;
        visualize = 'false';
        fprintf('  Extracting 100 salient vertices...\n');
        [vertices,normals,colors,faces,saliency,saliencymark] = ExtractSalientVertices(dir,filename,param,visualize); 
         fprintf('  extraction ended. Set param vector for different settings \n');
    end
    if (nargin ==3 && size(varargin,2)==1)
        
        if(isnumeric(varargin{1}))%varargin converte a 1 il true eil 'true'
            fprintf('  Extracting salient vertices...\n');
            [vertices,normals,colors,faces,saliency,saliencymark] = ExtractSalientVertices(dir,filename,varargin{1},'false');
        else
            param = 100;           
            fprintf('  Extracting 100 salient vertices...\n');
            %vdebug = varargin(1);
            if(strcmp(varargin{1},'true'))
            %if(islogical(varargin{1}))
            [vertices,normals,colors,faces,saliency,saliencymark] = ExtractSalientVertices(dir,filename,param,varargin{1});
            else
            [vertices,normals,colors,faces,saliency,saliencymark] = ExtractSalientVertices(dir,filename,param,'false');
            end
        end
        fprintf('  extraction ended. Set param vector for different settings \n');
    end
    if(nargin==4)
        if(isnumeric(varargin{1}) && (strcmp(varargin{2},'true') || strcmp(varargin{2},'false')))        
        fprintf('  Extracting salient vertices,please wait...\n');
        param = varargin{1};
        [vertices,normals,colors,faces,saliency,saliencymark] = ExtractSalientVertices(dir,filename,param,'true');
        fprintf('  extraction ended. Set param vector for different settings \n');
        end
    end

%[vertices,normals,colors,faces,saliency,saliencymark] = ExtractSalientVertices(dir,filename,param,visualize);

end